@@ -1,7 +1,9 @@
 /*
-//@line 38 "/builds/slave/m-beta-linuxqt-xr/build/toolkit/mozapps/extensions/amContentHandler.js"
+//@line 38 "/builds/slave/m-beta-lnx-xr/build/toolkit/mozapps/extensions/amContentHandler.js"
 */
 
+"use strict";
+
 const Cc = Components.classes;
 const Ci = Components.interfaces;
 const Cr = Components.results;
