@@ -1,4 +1,4 @@
-//@line 38 "/builds/slave/m-beta-lnx-xr/build/toolkit/content/aboutSupport.js"
+//@line 38 "/builds/slave/m-beta-linuxqt-xr/build/toolkit/content/aboutSupport.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -37,6 +37,8 @@ const PREFS_WHITELIST = [
   "layout.css.dpi",
   "network.",
   "places.",
+  "plugin.",
+  "plugins.",
   "print.",
   "privacy.",
   "security.",
@@ -208,7 +210,7 @@ function populateGraphicsSection() {
     pushInfoRow(trGraphics, "driverVersion", gfxInfo.adapterDriverVersion);
     pushInfoRow(trGraphics, "driverDate", gfxInfo.adapterDriverDate);
 
-//@line 275 "/builds/slave/m-beta-lnx-xr/build/toolkit/content/aboutSupport.js"
+//@line 286 "/builds/slave/m-beta-linuxqt-xr/build/toolkit/content/aboutSupport.js"
 
     var webglrenderer;
     var webglenabled;
@@ -219,9 +221,9 @@ function populateGraphicsSection() {
       webglrenderer = false;
       webglenabled = false;
     }
-//@line 293 "/builds/slave/m-beta-lnx-xr/build/toolkit/content/aboutSupport.js"
+//@line 304 "/builds/slave/m-beta-linuxqt-xr/build/toolkit/content/aboutSupport.js"
     var webglfeature = gfxInfo.FEATURE_WEBGL_OPENGL;
-//@line 295 "/builds/slave/m-beta-lnx-xr/build/toolkit/content/aboutSupport.js"
+//@line 306 "/builds/slave/m-beta-linuxqt-xr/build/toolkit/content/aboutSupport.js"
     pushFeatureInfoRow(trGraphics, "webglRenderer", webglfeature, webglenabled, webglrenderer);
 
     appendChildren(graphics_tbody, trGraphics);
@@ -256,9 +258,9 @@ function populateGraphicsSection() {
   if (acceleratedWindows) {
     msg += " " + mgrType;
   } else {
-//@line 332 "/builds/slave/m-beta-lnx-xr/build/toolkit/content/aboutSupport.js"
+//@line 343 "/builds/slave/m-beta-linuxqt-xr/build/toolkit/content/aboutSupport.js"
     var feature = gfxInfo.FEATURE_OPENGL_LAYERS;
-//@line 334 "/builds/slave/m-beta-lnx-xr/build/toolkit/content/aboutSupport.js"
+//@line 345 "/builds/slave/m-beta-linuxqt-xr/build/toolkit/content/aboutSupport.js"
     var errMsg = errorMessageForFeature(feature);
     if (errMsg)
       msg += ". " + errMsg;
@@ -390,7 +392,7 @@ function createTextForElement(elem) {
   text = text.replace(/\n\n\n+/g, "\n\n");
 
   // Actual CR/LF pairs are needed for some Windows text editors.
-//@line 468 "/builds/slave/m-beta-lnx-xr/build/toolkit/content/aboutSupport.js"
+//@line 479 "/builds/slave/m-beta-linuxqt-xr/build/toolkit/content/aboutSupport.js"
 
   return text;
 }
