@@ -1,4 +1,6 @@
-//@line 38 "/builds/slave/m-beta-linuxqt-xr/build/toolkit/mozapps/extensions/content/about.js"
+//@line 38 "/builds/slave/m-beta-lnx-xr/build/toolkit/mozapps/extensions/content/about.js"
+
+"use strict";
 
 function init() {
   var addon = window.arguments[0];
