@@ -1,7 +1,9 @@
-//@line 38 "/builds/slave/m-beta-linuxqt-xr/build/toolkit/mozapps/extensions/content/update.js"
+//@line 38 "/builds/slave/m-beta-lnx-xr/build/toolkit/mozapps/extensions/content/update.js"
 
 // This UI is only opened from the Extension Manager when the app is upgraded.
 
+"use strict";
+
 const PREF_UPDATE_EXTENSIONS_ENABLED            = "extensions.update.enabled";
 const PREF_XPINSTALL_ENABLED                    = "xpinstall.enabled";
 
